# Robotiq 85mm 2-Finger-Adaptive-Gripper 

This package contains the URDF files describing the 85mm stroke gripper from robotiq, also known as series **C3**.

To test the gripper URDF description type 

```
roslaunch robotiq_2f_85_gripper_visualization test_2f_85_model.launch 
```
## Robot Visual
![85](https://user-images.githubusercontent.com/8356912/49428405-45a6ef00-f7a6-11e8-822b-c6870c39d445.png)

## Robot Collision 
![852](https://user-images.githubusercontent.com/8356912/49428404-450e5880-f7a6-11e8-82a8-564247ebe7fc.png)

